@@ -2,8 +2,8 @@
 # imputation function for continuous variable
 # ==============================================================================
 
-mi.continuous <- function (formula, data = NULL, start = NULL, 
-                            n.iter = 100, draw.from.beta = TRUE, missing.index = NULL, ...  ) {
+mi.continuous <- function (formula, data = NULL, start = NULL,
+                            maxit = 100, draw.from.beta = TRUE, missing.index = NULL, ...  ) {
   call <- match.call()
   mf   <- match.call(expand.dots = FALSE)
   m    <- match(c("formula", "data"), names(mf), 0)
@@ -17,15 +17,15 @@ mi.continuous <- function (formula, data = NULL, start = NULL,
   if (length(dim(Y)) == 1) {
     nm <- rownames(Y)
     dim(Y) <- NULL
-    if (!is.null(nm)) 
+    if (!is.null(nm))
       names(Y) <- nm
   }
 #  X <- mf[,-1,drop=FALSE]
-#  namesD <- if(is.null(data)){ 
-#              NULL 
-#            }  
-#            else{ 
-#              deparse(substitute(data)) 
+#  namesD <- if(is.null(data)){
+#              NULL
+#            }
+#            else{
+#              deparse(substitute(data))
 #            }
   mis <- is.na(Y)
   n.mis <- if(is.null(missing.index)){
@@ -36,22 +36,22 @@ mi.continuous <- function (formula, data = NULL, start = NULL,
   if(is.null(missing.index)& any(mis)){
     missing.index <- mis
   }
-  
-           
+
+
   if(is.null(data)){
     data <- mf
   }
 
   # main program
-  if( !is.null( start ) ){ 
-    n.iter <- 50
+  if( !is.null( start ) ){
+    maxit <- 50
     start[is.na(start)] <- 0
   }
-  
-  bglm.imp    <- bayesglm( formula = formula, data = data, family = gaussian, 
-                            n.iter = n.iter, start = start, 
+
+  bglm.imp    <- bayesglm( formula = formula, data = data, family = gaussian,
+                            maxit = maxit, start = start,
                             drop.unused.levels = FALSE, Warning=FALSE, ...)
-  
+
   determ.pred <- predict(bglm.imp, newdata = data, type = "response" )
 
   if(n.mis>0){
@@ -77,12 +77,12 @@ mi.continuous <- function (formula, data = NULL, start = NULL,
   # return
   result <- new(c("mi.continuous", "mi.method"),
               model = vector("list", 0),
-              expected = numeric(0), 
+              expected = numeric(0),
               random = numeric(0))
   result@model$call        <- bglm.imp$call
   result@model$call$formula<- as.formula(formula)
   result@model$call$start  <- round(as.double(start), 2)
-  result@model$call$n.iter <- n.iter
+  result@model$call$maxit <- maxit
   result@model$coefficients <- coef(bglm.imp)
   result@model$sigma       <- sigma.hat(bglm.imp)
   result@model$dispersion  <- bglm.imp$dispersion
