@@ -12,7 +12,7 @@ setMethod("residuals", signature(object = "mi.method"),
 
 setMethod("residuals", signature(object = "mi.binary"), 
   function(object, y){
-  .dichot(y) - fitted(object)
+  .factor2num(.dichot(y)) - fitted(object)
 }
 )
 
@@ -49,7 +49,7 @@ setMethod("resid", signature(object = "mi.method"),
 
 setMethod("resid", signature(object = "mi.binary"), 
   function(object, y){
-  .dichot(y) - fitted(object)
+  .factor2num(y)(.dichot(y)) - fitted(object)
 }
 )
 
